import { Fragment, useEffect, useState } from 'react';
import { useUserStore } from '../store';
import { useShallow } from 'zustand/react/shallow';
import EditOutlined from '@ant-design/icons/EditOutlined';
import SaveOutlined from '@ant-design/icons/SaveOutlined';
import DeleteOutlined from '@ant-design/icons/DeleteOutlined';
import LeftOutlined from '@ant-design/icons/LeftOutlined';
import PlusOutlined from '@ant-design/icons/PlusOutlined';
import clsx from 'clsx';
import { isObjectNull } from '@/utils/is-null';
import { CardBlank } from '@kevisual/components/card/CardBlank.tsx';
import { Dialog, ButtonGroup, Button, DialogContent, DialogTitle } from '@mui/material';
import { IconButton } from '@kevisual/components/button/index.tsx';
import { useTranslation } from 'react-i18next';
import { useModal } from '@kevisual/components/modal/Confirm.tsx';
import { TextField } from '@mui/material';
import { useForm, Controller } from 'react-hook-form';
import { pick } from 'lodash-es';

const FormModal = () => {
  const { control, handleSubmit, reset } = useForm();
  const userStore = useUserStore(
    useShallow((state) => {
      return {
        showEdit: state.showEdit,
        setShowEdit: state.setShowEdit,
        formData: state.formData,
        updateData: state.updateData,
        setFormData: state.setFormData,
      };
    }),
  );

  useEffect(() => {
    const open = userStore.showEdit;
    if (open) {
      const isNull = isObjectNull(userStore.formData);
      if (isNull) {
        reset({});
      } else reset(userStore.formData);
    }
    return () => {
      reset({});
    };
  }, [userStore.showEdit]);

  const onFinish = (values: any) => {
    const pickValues = pick(values, ['id', 'username', 'description']);
    userStore.updateData(pickValues);
  };

  const onClose = () => {
    userStore.setShowEdit(false);
    reset({});
    userStore.setFormData({});
  };

  const isEdit = userStore.formData.id;
  const { t } = useTranslation();

  return (
    <Dialog
      open={userStore.showEdit}
      onClose={() => userStore.setShowEdit(false)}
      sx={{
        '& .MuiDialog-paper': {
          width: '800px',
        },
      }}>
      <DialogTitle>{isEdit ? t('Edit') : t('Add')}</DialogTitle>
      <DialogContent>
        <form onSubmit={handleSubmit(onFinish)}>
          <Controller name='username' control={control} defaultValue='' render={({ field }) => <TextField {...field} label='username' fullWidth />} />
          <Controller
            name='description'
            control={control}
            defaultValue=''
            render={({ field }) => <TextField {...field} label='description' multiline rows={4} fullWidth />}
          />
          <div>
            <Button type='submit' variant='contained'>
              {t('Submit')}
            </Button>
            <Button className='ml-2' type='button' onClick={onClose}>
              {t('Cancel')}
            </Button>
          </div>
        </form>
      </DialogContent>
    </Dialog>
  );
};

export const List = () => {
  const [modal, contextHolder] = useModal();
  const userStore = useUserStore(
    useShallow((state) => {
      return {
        setFormData: state.setFormData,
        setShowEdit: state.setShowEdit,
        list: state.list,
        deleteData: state.deleteData,
        getList: state.getList,
        loading: state.loading,
        updateData: state.updateData,
        formData: state.formData,
      };
    }),
  );
  useEffect(() => {
    userStore.getList();
  }, []);

  const onAdd = () => {
    userStore.setFormData({});
    userStore.setShowEdit(true);
  };
  return (
    <div className='w-full h-full flex'>
      <div className='p-2'>
        <IconButton onClick={onAdd} variant='contained'>
          <PlusOutlined />
        </IconButton>
      </div>
      <div className='flex grow overflow-hidden h-full'>
        <div className='grow overflow-auto scrollbar bg-gray-100'>
          <div className='flex  flex-wrap   gap-x-10 gap-y-4 rounded pt-10  justify-center'>
            {userStore.list.length > 0 &&
              userStore.list.map((item) => {
                return (
                  <Fragment key={item.id}>
                    <div
                      className='flex text-sm gap flex-col w-[400px] max-h-[400px] bg-white p-4 rounded-lg'
                      key={item.id}
                      onClick={() => {
                        // userStore.setFormData(item);
                      }}>
                      <div className='px-4 cursor-pointer'>
                        <div
                          className='font-bold'
                          onClick={(e) => {
                            e.stopPropagation();
                            // message.success('copy code success');
                          }}>
                          {item.username || '-'}
                        </div>
                        <div className='font-light text-xs mt-2'>{item.description ? item.description : '-'}</div>
                      </div>
                      <div className='flex mt-2 '>
                        <ButtonGroup
                          variant='contained'
                          color='primary'
                          sx={{ color: 'white', '& .MuiButton-root': { color: 'white', minWidth: '32px', width: '32px', height: '32px', padding: '6px' } }}>
                          <Button
                            onClick={(e) => {
                              userStore.setFormData(item);
                              userStore.setShowEdit(true);
                              e.stopPropagation();
                            }}>
                            <EditOutlined />
                          </Button>
                          <Button
                            onClick={(e) => {
                              modal.confirm({
                                title: 'Delete',
                                content: 'Are you sure delete this data?',
                                onOk: () => {
                                  userStore.deleteData(item.id);
                                },
                              });
                              e.stopPropagation();
                            }}>
                            <DeleteOutlined />
                          </Button>
                        </ButtonGroup>
                      </div>
                    </div>
                  </Fragment>
                );
              })}
            <CardBlank className='w-[400px]' />
            {userStore.list.length == 0 && (
              <div className='text-center' key={'no-data'}>
                No Data
              </div>
            )}
          </div>
        </div>
      </div>
      <FormModal />
      {contextHolder}
    </div>
  );
};
